#
# spec file for package neomutt
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           neomutt
Version:        20201120
Release:        lp152.2.3.1
Summary:        A command line mail reader (or MUA), a fork of Mutt with added features
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Email/Clients
URL:            https://neomutt.org
Source:         https://github.com/neomutt/neomutt/archive/%{version}.tar.gz
Source2:        https://github.com/neomutt/neomutt/releases/download/%{version}/%{version}.tar.gz.sig
Source3:        https://flatcap.org/id/richard.russon.neomutt.asc#/%{name}.keyring
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cyrus-sasl-devel
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  gawk
BuildRequires:  gdbm-devel
BuildRequires:  gettext
BuildRequires:  krb5-devel
BuildRequires:  libdb-4_8-devel
BuildRequires:  libgnutls-devel
BuildRequires:  libgpgme-devel
BuildRequires:  libidn-devel
BuildRequires:  libkyotocabinet-devel
BuildRequires:  libtool
BuildRequires:  lmdb-devel
BuildRequires:  lua-devel
BuildRequires:  ncurses-devel
BuildRequires:  notmuch-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  w3m
BuildRequires:  xsltproc
BuildRequires:  zlib-devel
Recommends:     neomutt-doc
Recommends:     neomutt-lang

%description
NeoMutt is a command line mail reader based on Mutt, brings together many
new features. Can be installed in parallel with mutt.

%package doc
Summary:        Additional documentation for neomutt
Group:          Documentation/Other
Requires:       %{name} = %{version}
#Recommends:     perl(Expect)
BuildArch:      noarch

%description doc
Documentation for NeoMutt with neomuttrc examples for different environments
and requirements.

%lang_package macro

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
./configure	--prefix=%{_prefix}			\
		--docdir=%{_docdir}/neomutt	\
		--with-mailpath=%{_localstatedir}/mail	\
		--kyotocabinet			\
		--lua				\
		--lmdb				\
		--gnutls			\
		--gpgme				\
		--notmuch			\
		--sasl				\
		--gss				\
		--idn				\
		--mixmaster			\
		--zlib

make %{?_smp_mflags}

%install
%make_install

%find_lang neomutt

%files
%config(noreplace) %{_sysconfdir}/neomuttrc
%license %{_docdir}/%{name}/LICENSE.md
%{_bindir}/neomutt
%{_mandir}/man1/neomutt.1%{?ext_man}
%{_mandir}/man5/neomuttrc.5%{?ext_man}
%dir %{_prefix}/libexec
%dir %{_prefix}/libexec/neomutt
%{_prefix}/libexec/neomutt/pgpewrap
%{_prefix}/libexec/neomutt/smime_keys
%{_mandir}/man1/pgpewrap_neomutt.1%{?ext_man}
%{_mandir}/man1/smime_keys_neomutt.1%{?ext_man}
%{_mandir}/man5/mbox_neomutt.5%{?ext_man}
%{_mandir}/man5/mmdf_neomutt.5%{?ext_man}
# this file is used from the default /etc/neomuttrc and moved from neomutt-doc
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/manual.txt

%files doc
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/README*
%doc %{_docdir}/%{name}/AUTHORS.md
%doc %{_docdir}/%{name}/ChangeLog.md
%doc %{_docdir}/%{name}/CODE_OF_CONDUCT.md
%doc %{_docdir}/%{name}/CONTRIBUTING.md
%doc %{_docdir}/%{name}/INSTALL.md
%doc %{_docdir}/%{name}/SECURITY.md
%dir %{_docdir}/%{name}/
%doc %{_docdir}/%{name}/*.html
%doc %{_docdir}/%{name}/mime.types
%doc %{_docdir}/%{name}/smime-notes.txt
%dir %doc %{_docdir}/%{name}/colorschemes/
%doc %{_docdir}/%{name}/colorschemes/*.neomuttrc
%dir %doc %{_docdir}/%{name}/keybase/
%doc %{_docdir}/%{name}/keybase/*
%dir %doc %{_docdir}/%{name}/logo/
%doc %{_docdir}/%{name}/logo/neomutt*
%dir %doc %{_docdir}/%{name}/samples/
%doc %{_docdir}/%{name}/samples/*.pl
%doc %{_docdir}/%{name}/samples/*.rc
%doc %{_docdir}/%{name}/samples/colors.*
%doc %{_docdir}/%{name}/samples/sample.*
%dir %doc %{_docdir}/%{name}/vim-keys/
%doc %{_docdir}/%{name}/vim-keys/*
%dir %doc %{_docdir}/%{name}/hcache-bench/
%doc %{_docdir}/%{name}/hcache-bench/README.md
%doc %{_docdir}/%{name}/hcache-bench/neomuttrc
%doc %{_docdir}/%{name}/hcache-bench/neomutt-hcache-bench.sh
%dir %doc %{_docdir}/%{name}/lua/
%doc %{_docdir}/%{name}/lua/test_lua-api_runner.neomuttrc
%doc %{_docdir}/%{name}/lua/test_lua-api_spec.lua

%files lang -f %{name}.lang

%changelog
* Sat Nov 21 2020 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream signing key and validate source signature
* Sat Nov 21 2020 Kai Liu <kai.liu@suse.com>
- Update to 20201120. Address boo#1179035, CVE-2020-28896.
  * Security
  - imap: close connection on all failures
  * Features
  - alias: add function to Alias/Query dialogs
  - config: add validators for {imap,smtp,pop}_authenticators
  - config: warn when signature file is missing or not readable
  - smtp: support for native SMTP LOGIN auth mech
  - notmuch: show originating folder in index
  * Bug Fixes
  - sidebar: prevent the divider colour bleeding out
  - sidebar: fix <sidebar-{next,prev}-new>
  - notmuch: fix query for current email
  - restore shutdown-hook functionality
  - crash in reply-to
  - user-after-free in folder-hook
  - fix some leaks
  - fix application of limits to modified mailboxes
  - write Date header when postponing
  * Translations
  - 100%% Lithuanian
  - 100%% Czech
  - 70%% Turkish
  * Docs
  - Document that $sort_alias affects the query menu
  * Build
  - improve ASAN flags
  - add SASL and S/MIME to --everything
  - fix contrib (un)install
  * Code
  - my_hdr compose screen notifications
  - add contracts to the MXAPI
  - maildir refactoring
  - further reduce the use of global variables
  * Upstream
  - Add $count_alternatives to count attachments inside alternatives
- Changes from 20200925
  * Features
  - Compose: display user-defined headers
  - Address Book / Query: live sorting
  - Address Book / Query: patterns for searching
  - Config: Add '+=' and '-=' operators for String Lists
  - Config: Add '+=' operator for Strings
  - Allow postfix query ':setenv NAME?' for env vars
  * Bug Fixes
  - Fix crash when searching with invalid regexes
  - Compose: Prevent infinite loop of send2-hooks
  - Fix sidebar on new/removed mailboxes
  - Restore indentation for named mailboxes
  - Prevent half-parsing an alias
  - Remove folder creation prompt for POP path
  - Show error if $message_cachedir doesn't point to a valid directory
  - Fix tracking LastDir in case of IMAP paths with Unicode characters
  - Make sure all mail gets applied the index limit
  - Add warnings to -Q query CLI option
  - Fix index tracking functionality
  * Changed Config
  - Add $compose_show_user_headers (yes)
  * Translations
  - 100%% Czech
  - 100%% Lithuanian
  - Split up usage strings
  * Build
  - Run shellcheck on hcachever.sh
  - Add the Address Sanitizer
  - Move compose files to lib under compose/
  - Move address config into libaddress
  - Update to latest acutest - fixes a memory leak in the unit tests
  * Code
  - Implement ARRAY API
  - Deglobalised the Config Sort functions
  - Refactor the Sidebar to be Event-Driven
  - Refactor the Color Event
  - Refactor the Commands list
  - Make ctx_update_tables private
  - Reduce the scope/deps of some Validator functions
  - Use the Email's IMAP UID instead of an increasing number as index
  - debug: log window focus
- Removed neomutt-sidebar-abbreviate-shorten-what-user-sees.patch.
  No longer needed.
- Misc spec file cleanups.
* Sun Aug 23 2020 Kai Liu <kai.liu@suse.com>
- Update to 20200821:
  * Bug Fixes
  - fix maildir flag generation
  - fix query notmuch if file is missing
  - notmuch: don't abort sync on error
  - fix type checking for send config variables
  * Changed Config
  - $sidebar_format - Use %%D rather than %%B for named mailboxes
  * Translations
  - 96%% Lithuanian
  - 90%% Polish
- add neomutt-sidebar-abbreviate-shorten-what-user-sees.patch
  * fix(sidebar): abbreviate/shorten what user sees
* Tue Aug 18 2020 Kai Liu <kai.liu@suse.com>
- Fix sidebar mailbox name display problem. Patch from the yet to
  be merge upstream commit:
  https://github.com/neomutt/neomutt/commit/a6f91bc9c890581cff189e143d86e656cab6d2dc
* Mon Aug 17 2020 Kai Liu <kai.liu@suse.com>
- Enable --zlib configure option explicitely. In version 20200814 if
  it's not enabled header cache compression will not be turned on,
  unlike in previous versions which would turn it on when zlib is
  detected.
* Sat Aug 15 2020 Kai Liu <kai.liu@suse.com>
- Update to 20200814:
  * Notes
  - Add one-liner docs to config items
    See: neomutt -O -Q smart_wrap
  - Remove the built-in editor
    A large unused and unusable feature
  * Security
  - Add mitigation against DoS from thousands of parts
    boo#1179113
  * Features
  - Allow index-style searching in postpone menu
  - Open NeoMutt using a mailbox name
  - Add cd command to change the current working directory
  - Add tab-completion menu for patterns
  - Allow renaming existing mailboxes
  - Check for missing attachments in alternative parts
  - Add one-liner docs to config items
  * Bug Fixes
  - Fix logic in checking an empty From address
  - Fix Imap crash in cmd_parse_expunge()
  - Fix setting attributes with S-Lang
  - Fix: redrawing of $pager_index_lines
  - Fix progress percentage for syncing large mboxes
  - Fix sidebar drawing in presence of indentation + named mailboxes
  - Fix retrieval of drafts when "postponed" is not in the mailboxes list
  - Do not add comments to address group terminators
  - Fix alias sorting for degenerate addresses
  - Fix attaching emails
  - Create directories for nonexistent file hcache case
  - Avoid creating mailboxes for failed subscribes
  - Fix crash if rejecting cert
  * Changed Config
  - Add $copy_decode_weed, $pipe_decode_weed, $print_decode_weed
  - Change default of $crypt_protected_headers_subject to "..."
  - Add default keybindings to history-up/down
  * Translations
  - 100%% Czech
  - 100%% Spanish
  * Build
  - Allow building against Lua 5.4
  - Fix when sqlite3.h is missing
  * Docs
  - Add a brief section on stty to the manual
  - Update section "Terminal Keybindings" in the manual
  - Clarify PGP Pseudo-header S<id> duration
  * Code
  - Clean up String API
  - Make the Sidebar more independent
  - De-centralise the Config Variables
  - Refactor dialogs
  - Refactor: Help Bar generation
  - Make more APIs Context-free
  - Adjust the edata use in Maildir and Notmuch
  - Window refactoring
  - Convert libsend to use Config functions
  - Refactor notifications to reduce noise
  - Convert Keymaps to use STAILQ
  - Track currently selected email by msgid
  - Config: no backing global variable
  - Add events for key binding
  * Upstream
  - Fix imap postponed mailbox use-after-free error
  - Speed up thread sort when many long threads exist
  - Fix ~v tagging when switching to non-threaded sorting
  - Add message/global to the list of known "message" types
  - Print progress meter when copying/saving tagged messages
  - Remove ansi formatting from autoview generated quoted replies
  - Change postpone mode to write Date header too
  - Unstuff format=flowed
* Sun Jul  5 2020 Kai Liu <kai.liu@suse.com>
- Update to 20200626:
  * Bug Fixes
  - Avoid opening the same hcache file twice
  - Re-open Mailbox after folder-hook
  - Fix the matching of the spoolfile Mailbox
  - Fix link-thread to link all tagged emails
  * Changed Config
  - Add $tunnel_is_secure config, defaulting to true
  * Upstream
  - Don't check IMAP PREAUTH encryption if $tunnel is in use
  - Add recommendation to use $ssl_force_tls
- Changes from 20200501:
  * Security
  - Abort GnuTLS certificate check if a cert in the chain is rejected
    CVE-2020-14154 bsc#1172906
  - TLS: clear data after a starttls acknowledgement
    CVE-2020-14954 bsc#1173197
  - Prevent possible IMAP MITM via PREAUTH response
    CVE-2020-14093 bsc#1172935
  * Features
  - add config operations +=/-= for number,long
  - Address book has a comment field
  - Query menu has a comment field
  * Contrib
    sample.neomuttrc-starter: Do not echo prompted password
  * Bug Fixes
  - make "news://" and "nntp://" schemes interchangeable
  - Fix CRLF to LF conversion in base64 decoding
  - Double comma in query
  - compose: fix redraw after history
  - Crash inside empty query menu
  - mmdf: fix creating new mailbox
  - mh: fix creating new mailbox
  - mbox: error out when an mbox/mmdf is a pipe
  - Fix list-reply by correct parsing of List-Post headers
  - Decode references according to RFC2047
  - fix tagged message count
  - hcache: fix keylen not being considered when building the full key
  - sidebar: fix path comparison
  - Don't mess with the original pattern when running IMAP searches
  - Handle IMAP "NO" resps by issuing a msg instead of failing badly
  - imap: use the connection delimiter if provided
  - Memory leaks
  * Changed Config
  - $alias_format default changed to include %%c comment
  - $query_format default changed to include %%e extra info
  * Translations
  - 100%% Lithuanian
  - 84%% French
  - Log the translation in use
  * Docs
  - Add missing commands unbind, unmacro to man pages
  * Build
  - Check size of long using LONG_MAX instead of __WORDSIZE
  - Allow ./configure to not record cflags
  - fix out-of-tree build
  - Avoid locating gdbm symbols in qdbm library
  * Code
  - Refactor unsafe TAILQ returns
  - add window notifications
  - flip negative ifs
  - Update to latest acutest.h
  - test: add store tests
  - test: add compression tests
  - graphviz: email
  - make more opcode info available
  - refactor: main_change_folder()
  - refactor: mutt_mailbox_next()
  - refactor: generate_body()
  - compress: add {min,max}_level to ComprOps
  - emphasise empty loops: "// do nothing"
  - prex: convert is_from() to use regex
  - Refactor IMAP's search routines
* Fri May 22 2020 Kai Liu <kai.liu@suse.com>
- Update to 20200501:
  * Bug Fixes
  - Make sure buffers are initialized on error
  - fix(sidebar): use abbreviated path if possible
  * Translations
  - 100%% Lithuanian
  * Docs
  - make header cache config more explicit
- Changes from 20200424:
  * Bug Fixes
  - Fix history corruption
  - Handle pretty much anything in a URL query part
  - Correctly parse escaped characters in header phrases
  - Fix crash reading received header
  - Fix sidebar indentation
  - Avoid crashing on failure to parse an IMAP mailbox
  - Maildir: handle deleted emails correctly
  - Ensure OP_NULL is always first
  * Translations
  - 100%% Czech
  * Build
  - cirrus: enable pcre2, make pkgconf a special case
  - Fix finding pcre2 w/o pkgconf
  - build: tdb.h needs size_t, bring it in with stddef.h
- Changes from 20200417:
  * Features
  - Fluid layout for Compose Screen, see: vimeo.com/407231157
  - Trivial Database (TDB) header cache backend
  - RocksDB header cache backend
  - Add <sidebar-first> and <sidebar-last> functions
  * Bug Fixes
  - add error for CLI empty emails
  - Allow spaces and square brackets in paths
  - browser: fix hidden mailboxes
  - fix initial email display
  - notmuch: fix time window search.
  - fix resize bugs
  - notmuch: fix entire-thread: update current email pointer
  - sidebar: support indenting and shortening of names
  - Handle variables inside backticks in sidebar_whitelist
  - browser: fix mask regex error reporting
  * Translations
  - 100%% Lithuanian
  - 99%% Chinese (simplified)
  * Build
  - Use regexes for common parsing tasks: urls, dates
  - Add configure option --pcre2 -- Enable PCRE2 regular expressions
  - Add configure option --tdb -- Use TDB for the header cache
  - Add configure option --rocksdb -- Use RocksDB for the header cache
  - Create libstore (key/value backends)
  - Update to latest autosetup
  - Update to latest acutest.h
  - Rename doc/ directory to docs/
  - make: fix location of .Po dependency files
  - Change libcompress to be more universal
  - Fix test fails on х32
  - fix uidvalidity to unsigned 32-bit int
  * Code
  - Increase test coverage
  - Fix memory leaks
  - Fix null checks
  * Upstream
  - Buffer refactoring
  - Fix use-after-free in mutt_str_replace()
  - Clarify PGP Pseudo-header S<id> duration
  - Try to respect MUTT_QUIET for IMAP contexts too
  - Limit recurse depth when parsing mime messages
* Fri Mar 20 2020 Martin Rey <mrey@suse.com>
- Update to 20200320:
  * Bug Fixes
  - Fix COLUMNS env var
  - Fix sync after delete
  - Fix crash in notmuch
  - Fix sidebar indent
  - Fix emptying trash
  - Fix command line sending
  - Fix reading large address lists
  - Resolve symlinks only when necessary
  * Translations
  - lithuania 100%% Lithuanian
  - es 96%% Spanish
  * Docs
  - Include OpenSSL/LibreSSL/GnuTLS version in neomutt -v output
  - Fix case of GPGME and SQLite
  * Build
  - Create libcompress (lz4, zlib, zstd)
  - Create libhistory
  - Create libbcache
  - Move zstrm to libconn
  * Code
  - Add more test coverage
  - Rename magic to type
  - Use mutt_file_fopen() on config variables
  - Change commands to use intptr_t for data
* Fri Mar 13 2020 Martin Rey <mrey@suse.com>
- Update to 20200313:
  * Window layout
  - Sidebar is only visible when it's usable.
  * Features
  - UI: add number of old messages to sidebar_format
  - UI: support ISO 8601 calendar date
  - UI: fix commands that don’t need to have a non-empty mailbox
    to be valid
  - PGP: inform about successful decryption of inline PGP
    messages
  - PGP: try to infer the signing key from the From address
  - PGP: enable GPGMe by default
  - Notmuch: use query as name for vfolder-from-query
  - IMAP: add network traffic compression
    (COMPRESS=DEFLATE, RFC4978)
  - Header cache: add support for generic header cache
    compression
  * Bug Fixes
  - Fix uncollapse_jump
  - Only try to perform entire-thread on maildir/mh mailboxes
  - Fix crash in pager
  - Avoid logging single new lines at the end of header fields
  - Fix listing mailboxes
  - Do not recurse a non-threaded message
  - Fix initial window order
  - Fix leaks on IMAP error paths
  - Notmuch: compose(attach-message): support notmuch backend
  - Fix IMAP flag comparison code
  - Fix $move for IMAP mailboxes
  - Maildir: maildir_mbox_check_stats should only update mailbox
    stats if requested
  - Fix unmailboxes for virtual mailboxes
  - Maildir: sanitize filename before hashing
  - OAuth: if 'login' name isn't available use 'user'
  - Add error message on failed encryption
  - Fix a bunch of crashes
  - Force C locale for email date
  - Abort if run without a terminal
  * Changed Config
  - $crypt_use_gpgme - Now defaults to 'yes' (enabled)
  - $abort_backspace - Hitting backspace against an empty prompt
    aborts the prompt
  - $abort_key - String representation of key to abort prompts
  - $arrow_string - Use an custom string for arrow_cursor
  - $crypt_opportunistic_encrypt_strong_keys - Enable encryption
    only when strong a key is available
  - $header_cache_compress_dictionary - Filepath to dictionary
    for zstd compression
  - $header_cache_compress_level - Level of compression for
    method
  - $header_cache_compress_method - Enable generic hcache
    database compression
  - $imap_deflate - Compress network traffic
  - $smtp_user - Username for the SMTP server
  * Translations
  - 100%% Lithuanian
  - 81%% Spanish
  - 78%% Russian
  * Build
  - Add libdebug
  - Rename public headers to lib.h
  - Create libcompress for compressed folders code
  * Code
  - Refactor Windows and Dialogs
  - Lots of code tidying
  - Refactor: mutt_addrlist_{search,write}
  - Lots of improvements to the Config code
  - Use Buffers more pervasively
  - Unify API function naming
  - Rename library shared headers
  - Refactor libconn gui dependencies
  - Refactor: init.[ch]
  - Refactor config to use subsets
  - Config: add path type
  - Remove backend deps from the connection code
  * Upstream
  - Allow ~b ~B ~h patterns in send2-hook
  - Rename smime oppenc mode parameter to get_keys_by_addr()
  - Add $crypt_opportunistic_encrypt_strong_keys config var
  - Fix crash when polling a closed ssl connection
  - Turn off auto-clear outside of autocrypt initialization
  - Add protected-headers="v1" to Content-Type when protecting
    headers
  - Fix segv in IMAP postponed menu caused by reopen_allow
  - Adding ISO 8601 calendar date
  - Fix $fcc_attach to not prompt in batch mode
  - Convert remaining mutt_encode_path() call to use struct
    Buffer
  - Fix rendering of replacement_char when Charset_is_utf8
  - Update to latest acutest.h
* Fri Jan 31 2020 Martin Rey <mrey@suse.com>
- Update to 20191207:
  * Features:
  - compose: draw status bar with highlights
  * Bug Fixes:
  - crash opening notmuch mailbox
  - crash in mutt_autocrypt_ui_recommendation
  - Avoid negative allocation
  - Mbox new mail
  - Setting of DT_MAILBOX type variables from Lua
  - imap: empty cmdbuf before connecting
  - imap: select the mailbox on reconnect
  - compose: fix attach message
  * Build:
  - make files conditional
  * Code:
  - enum-ify log levels
  - fix function prototypes
  - refactor virtual email lookups
  - factor out global Context
- Changes from 20191129:
  * Features:
  - Add raw mailsize expando (%%cr)
  * Bug Fixes:
  - Avoid double question marks in bounce confirmation msg
  - Fix bounce confirmation
  - fix new-mail flags and behaviour
  - fix: browser <descend-directory>
  - fix ssl crash
  - fix move to trash
  - fix flickering
  - Do not check hidden mailboxes for new mail
  - Fix new_mail_command notifications
  - fix crash in examine_mailboxes()
  - fix crash in mutt_sort_threads()
  - fix: crash after sending
  - Fix crash in tunnel's conn_close
  - fix fcc for deep dirs
  - imap: fix crash when new mail arrives
  - fix colour 'quoted9'
  - quieten messages on exit
  - fix: crash after failed mbox_check
  - browser: default to a file/dir view when attaching a file
  * Changed Config:
  - Change $write_bcc to default off
  * Docs:
  - Add a bit more documentation about sending
  - Clarify $write_bcc documentation.
  - Update documentation for raw size expando
  - docbook: set generate.consistent.ids to make generated html
    reproducible
  * Build:
  - fix build/tests for 32-bit arches
  - tests: fix test that would fail soon
  - tests: fix context for failing idna tests
* Thu Nov 28 2019 Michael Vetter <mvetter@suse.com>
- Update to 20191111:
  Bug fixes:
  * browser: fix directory view
  * fix crash in mutt_extract_token()
  * force a screen refresh
  * fix crash sending message from command line
  * notmuch: use nm_default_uri if no mailbox data
  * fix forward attachments
  * fix: vfprintf undefined behaviour in body_handler
  * Fix relative symlink resolution
  * fix: trash to non-existent file/dir
  * fix re-opening of mbox Mailboxes
  * close logging as late as possible
  * log unknown mailboxes
  * fix crash in command line postpone
  * fix memory leaks
  * fix icommand parsing
  * fix new mail interaction with mail_check_recent
* Tue Jul 17 2018 kbabioch@suse.com
- Updated to 20180716
  * Feature: <check-stats> function
  * Lots of bug fixes and vulnerability fixes:
  - CVE-2018-14349: Fixed mishandling of NO response without message in
    imap/command.c (bnc#1101589)
  - CVE-2018-14350: Fixed stack-based buffer overflow for FETCH response with
    long INTERNALDATE field in imap/message.c (bnc#1101588)
  - CVE-2018-14351: Fixed mishandling of a long IMAP status mailbox literal
    count size in imap/command.c (bnc#1101583)
  - CVE-2018-14352: Fixed stack-based buffer overflow in imap_quote_string in
    imap/util.c (bnc#1101582)
  - CVE-2018-14353: Fixed integer underflow in imap_quote_string in
    imap/util.c (bnc#1101581)
  - CVE-2018-14354: Fixed arbitrary command execution via backquote
    characters, related to the mailboxes command associated with manual
    subscription or unsubscription (bnc#1101578)
  - CVE-2018-14355: Fixed directory traversal in mailbox name in imap/util.c
    (bnc#1101577)
  - CVE-2018-14356: Fixed mishandling of zero-length UID in pop.c
    (bnc#1101576)
  - CVE-2018-14357: Fixed arbitrary command execution via backquote
    characters, related to mailboxes command associated with automatic
    subscription (bnc#1101573)
  - CVE-2018-14358: Fixed stack-based buffer overflow for FETCH response with
    long RFC822.SIZE field (bnc#1101571)
  - CVE-2018-14359: Fixed buffer overflow via base64 data (bnc#1101570)
  - CVE-2018-14360: Fixed stack-based buffer overflow because of incorrect
    sscanf usage in nntp_add_group in newsrc.c (bnc#1101569)
  - CVE-2018-14361: Fixed an code flow issue in nntp.c, which would proceed
    even if memory allocation failed for messages data (bnc#1101568)
  - CVE-2018-14362: Fixed unsafe interaction with message-cache pathnames in
    pop.c (bnc#1101567)
  - CVE-2018-14363: Fixed unsafe interaction with cache pathnames (containing
    '/') in newsrc.c (bnc#1101566)
* Sun Jun 24 2018 dsterba@suse.cz
- spec: move license files to the main package
- update to 20180622
  * Features
  - Expand variables inside backticks
  - Honour SASL-IR IMAP capability in SASL PLAIN
  * Bug Fixes
  - Fix toggle-read
  - Do not truncate shell commands on ; or #
  - pager: index must be rebuilt on MUTT_REOPENED
  - Handle a BAD response in AUTH PLAIN w/o initial response
  - fcc_attach: Don't ask every time
  - Enlarge path buffers PATH_MAX (4096)
  - Move LSUB call from connection establishment to mailbox SELECTion
  * Translations
  - Update Chinese (Simplified): 100%%
  - Update Czech: 100%%
  - Update German: 100%%
  - Update Lithuanian: 100%%
  - Update Portuguese (Brazil): 100%%
  - Update Slovak: 59%%
  - Reduce duplication of messages
  * Code
  - Tidy up the mailbox API
  - Tidy up the header cache API
  - Tidy up the encryption API
  - Add doxygen docs for more functions
  - Refactor more structs to use STAILQ
* Sun May 13 2018 dsterba@suse.cz
- spec cleanup
- update to 20180512
  * Features
  - echo command
  - Add $browser_abbreviate_mailboxes
  - Add ~M pattern to match mime Content-Types
  - Add support for multipart/multilingual emails
  - Jump to a collapsed email
  - Add support for idn2 (IDNA2008)
  * Bug Fixes
  - Let mutt_ch_choose report conversion failure
  - minor IMAP string handling fixes
  * Translations
  - Chinese (Simplified) (100%%)
  - Czech (100%%)
  - German (100%%)
  - Lithuanian (62%%)
  - Portuguese (Brazil) (100%%)
  * Coverity defects
  - match prototypes to their functions
  - make logic clearer
  - reduce scope of variables
  - fix coverity defects
  * Docs
  - development: analysis
  - development: easy tasks
  - development: roadmap
  * Code
  - start refactoring libconn
  - split out progress functions
  - split out window functions
  - split out terminal setting
  - convert MyVars to use TAILQ
  - split mutt_file_{lock,unlock}
  - Move IDN version string to mutt/idna.c
  - refactor: init_locale()
  - Eliminate static variable in mutt_file_dirname
  * Tidy
  - test int functions against 0
  - rename lots of constants
  - rename lots of functions
  - sort lots of fields/definitions
  * Upstream
  - Increase account.user/login size to 128
  - Fix comparison of flags with multiple bits set
  - Change mutt_error call in mutt_gpgme_set_sender() to dprint
  - Improve the error message when a signature is missing
  - pager specific "show incoming mailboxes list" macro
  - Improve gss debug printing of status_string
  - Remove trailing null count from gss_buffer_desc.length field
  - Add a comment in auth_gss about RFCs and null-termination
  - Change prompt string for $crypt_verify_sig
* Thu Mar 22 2018 dsterba@suse.cz
- update to 20180323
  * Features
  - unify logging/messaging
  - add alert (blink) colors
  * Contrib
  - Vim syntax for NeoMutt log files
  * Bug Fixes
  - Fix progress bar range
  - notmuch: stop if db open fails
  - Improve index color cache flushing behavior
  - lua: fix crash when setting a string
  * Translations
  - Update Czech translation (100%%)
  - Update German translation (100%%)
  - Update Polish translation (94%%)
  - Update Portuguese (BR) translation (100%%)
  - Update Spanish translation (64%%)
  - Update Turkish translation (75%%)
  - Merge simliar messages
  * Docs
  - Clarify precedence of settings in config files
  - Fix subjectrx example in the manual
  * Website
  - Update Gentoo distro page
  - Devel: Static analysis
  * Build
  - Support —with-sysroot configure arg
  - Expose EXTRA_CFLAGS_FOR_BUILD and EXTRA_LDFLAGS_FOR_BUIlD
  - Update to latest autosetup
  - Make sure git_ver.h doesn't eat random 'g's out of tag names
  * Code
  - Refactor to reduce complexity
  - Refactor to reduce variables' scope
  - Sort functions/config to make docs more legible
* Tue Feb 27 2018 dsterba@suse.cz
- spec cleanup
- move manual.txt from neomutt-doc as it's bound to F1 key
* Thu Feb 22 2018 dsterba@suse.cz
- update to 20180223
  * Features
  - browser: `<goto-parent>` function bound to "p"
  - editor: `<history-search>` function bound to "Ctrl-r"
  - Cygwin support: https://www.neomutt.org/distro/cygwin
  - OpenSUSE support: https://www.neomutt.org/distro/suse
  - Upstream Homebrew support: Very soon - https://www.neomutt.org/distro/homebrew
  * Bug Fixes
  - gmail server-size search
  - nested-if: correctly handle "<" and ">" with %%?
  - display of special chars
  - lua: enable myvars
  - for pgpewrap in default gpg.rc
  - reply_regexp which wasn't formatted correctly.
  - parsing of urls containing '?'
  - out-of-bounds read in mutt_str_lws_len
  * Translations
  - Review fuzzy lt translations
  - Updated French translation
  * Website
  - Installation guide for Cygwin
  - Installation guide for OpenSUSE
  - Installation guide for CRUX
  * Build
  - check that DTDs are installed
  - autosetup improvements
  - option for which version of bdb to use
  - drop test for resizeterm -- it's always present
  * Code
  - split if's containing assignments
  - doxygen: add/improve comments
  - rename functions / parameters for consistency
  - add missing {}s for clarity
  - move functions to library
  - reduce scope of variables
  - boolify more variables
  - iwyu: remove unnecessary headers
  - name unicode chars
  - tailq: migrate parameter api
  - md5: refactor and tidy
  - rfc2047: refactor and tidy
  - buffer: improvements
  - create unit test framework
  - fix several coverity defects
  * Upstream
  - Fix s/mime certificate deletion bug
  - Disable message security if the backend is not available
  - Fix improper signed int conversion of IMAP uid and msn values
  - Change imap literal counts to parse and store unsigned ints
  - Fix imap status count range check
  - cmd_handle_fatal: make error message a bit more descriptive
  - Create pgp and s/mime default and sign_as key vars
  - Add missing setup calls when resuming encrypted drafts
  - mutt_pretty_size: show real number for small files
  - examine_directory: set directory/symlink size to zero
  - Add history-search function, bound to ctrl-r
  - Avoid a potential integer overflow if a Content-Length value is huge
* Thu Dec 28 2017 dsterba@suse.cz
- update to 2017-12-15
  - use autosetup instead of autotools
  - regression fixes
* Mon Nov 27 2017 dsterba@suse.cz
- neomutt 2017-12-08
